@@ -4,16 +4,9 @@ use strict;
 use warnings;
 use URI::URL();
 
-use parent qw(Firefox::Marionette::Element);
+use base qw(Firefox::Marionette::Element);
 
-our $VERSION = '1.67_02';
-
-sub new {
-    my ( $class, $element ) = @_;
-    my $self = $element;
-    bless $self, $class;
-    return $self;
-}
+our $VERSION = '1.14';
 
 sub url {
     my ($self) = @_;
@@ -85,11 +78,11 @@ __END__
 
 =head1 NAME
 
-Firefox::Marionette::Image - Represents an image from the images method
+Firefox::Marionette::Image - Represents a link from the links method
 
 =head1 VERSION
 
-Version 1.67_02
+Version 1.14
 
 =head1 SYNOPSIS
 
@@ -103,7 +96,7 @@ Version 1.67_02
 
 =head1 DESCRIPTION
 
-This module is a subclass of L<Firefox::Marionette::Element|Firefox::Marionette::Element> designed to be compatible with L<WWW::Mechanize::Image|WWW::Mechanize::Image>.
+This module is a super class of L<Firefox::Marionette::Element|Firefox::Marionete::Element> designed to be compatible with L<WWW::Mechanize::Image|WWW::Mechanize::Image>.
 
 =head1 SUBROUTINES/METHODS
 
@@ -127,10 +120,6 @@ returns the image height
 
 returns the name attribute, if any.
 
-=head2 new
-
-accepts an L<element|Firefox::Marionette::Element> as a parameter and returns an L<image|Firefox::Marionette::Image> object
-
 =head2 tag
 
 returns the tag (one of: "a", "area", "frame", "iframe" or "meta").
@@ -184,7 +173,7 @@ David Dick  C<< <ddick@cpan.org> >>
 
 =head1 LICENSE AND COPYRIGHT
 
-Copyright (c) 2024, David Dick C<< <ddick@cpan.org> >>. All rights reserved.
+Copyright (c) 2021, David Dick C<< <ddick@cpan.org> >>. All rights reserved.
 
 This module is free software; you can redistribute it and/or
 modify it under the same terms as Perl itself. See L<perlartistic/perlartistic>.
