@@ -4,16 +4,9 @@ use strict;
 use warnings;
 use URI::URL();
 
-use parent qw(Firefox::Marionette::Element);
+use base qw(Firefox::Marionette::Element);
 
-our $VERSION = '1.67_02';
-
-sub new {
-    my ( $class, $element ) = @_;
-    my $self = $element;
-    bless $self, $class;
-    return $self;
-}
+our $VERSION = '1.14';
 
 sub url {
     my ($self) = @_;
@@ -78,7 +71,7 @@ Firefox::Marionette::Link - Represents a link from the links method
 
 =head1 VERSION
 
-Version 1.67_02
+Version 1.14
 
 =head1 SYNOPSIS
 
@@ -96,7 +89,7 @@ Version 1.67_02
 
 =head1 DESCRIPTION
 
-This module is a subclass of L<Firefox::Marionette::Element|Firefox::Marionette::Element> designed to be compatible with L<WWW::Mechanize::Link|WWW::Mechanize::Link>.
+This module is a super class of L<Firefox::Marionette::Element|Firefox::Marionete::Element> designed to be compatible with L<WWW::Mechanize::Link|WWW::Mechanize::Link>.
 
 =head1 SUBROUTINES/METHODS
 
@@ -112,10 +105,6 @@ returns the base url to which all links are relative.
 
 returns the name attribute, if any.
 
-=head2 new
-
-accepts an L<element|Firefox::Marionette::Element> as a parameter and returns a L<link|Firefox::Marionette::Link> object
-
 =head2 tag
 
 returns the tag (one of: "a", "area", "frame", "iframe" or "meta").
@@ -169,7 +158,7 @@ David Dick  C<< <ddick@cpan.org> >>
 
 =head1 LICENSE AND COPYRIGHT
 
-Copyright (c) 2024, David Dick C<< <ddick@cpan.org> >>. All rights reserved.
+Copyright (c) 2021, David Dick C<< <ddick@cpan.org> >>. All rights reserved.
 
 This module is free software; you can redistribute it and/or
 modify it under the same terms as Perl itself. See L<perlartistic/perlartistic>.
